Learn R Programming

ramify (version 0.1.0)

ramify: ramify: additional matrix functionality

Description

Additional matrix functionality for R. Includes a new wrapper for the built-in matrix function that extends its functionality by allowing matrices to be created from character strings and lists. A number of convenience functions have also been added for users more familiar with MATLAB or Julia.

Arguments

Details

The main functions in this package are:
  • mat- matrix wrapper function
  • bmat- like the character method ofmat, but for block matrices
  • dmat- likemat, but instead returns a data frame
  • eye- creates an identity matrix
  • hcat/vcat- concatenate matrices
  • fill- fills a matrix with a particular value
  • flatten- flatten (i.e., collapse) a matrix to one dimension
  • inv- calculates the inverse of a square matrix
  • linspace/logspace- constructs a vector of linearly-spaced/logarithmically-spaced elements
  • ones/zeros- creates a matrix of all ones/zeros
  • rand/randn- creates a matrix of uniform/normally distributed random numbers
  • resize- resize a given matrix
  • size- returns the dimensions of the matrix
  • trues/falses- creates a matrix of allTRUEs/FALSEs