ramify: ramify: additional matrix functionality
Description
Additional matrix functionality for R. Includes a new wrapper for
the built-in matrix function that extends its functionality by allowing
matrices to be created from character strings and lists. A number of
convenience functions have also been added for users more familiar with
MATLAB or Julia.Details
The main functions in this package are:
mat- matrix wrapper functionbmat- like the character method ofmat, but for
block matricesdmat- likemat, but instead returns a data frameeye- creates an identity matrixhcat/vcat- concatenate matricesfill- fills a matrix with a particular valueflatten- flatten (i.e., collapse) a matrix to one dimensioninv- calculates the inverse of a square matrixlinspace/logspace- constructs a vector of linearly-spaced/logarithmically-spaced elementsones/zeros- creates a matrix of all ones/zerosrand/randn- creates a matrix of uniform/normally distributed random numbersresize- resize a given matrixsize- returns the dimensions of the matrixtrues/falses- creates a matrix of allTRUEs/FALSEs